"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const global_1 = __importDefault(require("./global"));
const os_1 = require("os");
const fs_1 = __importDefault(require("fs"));
exports.testEnv = () => {
    const OLD_ENV = process.env;
    beforeEach(() => {
        jest.resetModules();
        process.env = Object.assign({}, OLD_ENV);
        delete process.env.NODE_ENV;
    });
    afterEach(() => {
        process.env = OLD_ENV;
    });
};
exports.testChildProcess = () => {
    afterEach(() => {
        global_1.default.mockChildProcess.stdout = 'stdout';
        global_1.default.mockChildProcess.stderr = '';
        global_1.default.mockChildProcess.error = null;
    });
};
exports.setChildProcessParams = (params) => {
    if (typeof params.stdout === 'string') {
        global_1.default.mockChildProcess.stdout = params.stdout;
    }
    if (typeof params.stderr === 'string') {
        global_1.default.mockChildProcess.stderr = params.stderr;
    }
    if (params.error instanceof Error) {
        global_1.default.mockChildProcess.error = params.error;
    }
};
exports.testFs = (defaultExists = false) => {
    let existsData = [defaultExists];
    let callback = undefined;
    let count = 0;
    const spy = [];
    beforeEach(() => {
        spy.push(jest.spyOn(fs_1.default, 'writeFileSync').mockImplementation(jest.fn()));
        spy.push(jest.spyOn(fs_1.default, 'mkdirSync').mockImplementation(jest.fn()));
        spy.push(jest.spyOn(fs_1.default, 'existsSync').mockImplementation((path) => {
            if (typeof callback === 'function') {
                return callback(path);
            }
            // eslint-disable-next-line no-magic-numbers
            const result = count < existsData.length ? existsData[count] : existsData[existsData.length - 1];
            count++;
            return result;
        }));
    });
    afterEach(() => {
        spy.forEach(spy => spy.mockRestore());
        spy.length = 0;
        callback = undefined;
        existsData = [defaultExists];
        // eslint-disable-next-line no-magic-numbers
        count = 0;
    });
    return (flag) => {
        callback = undefined;
        if (typeof flag === 'function') {
            callback = flag;
        }
        else if (typeof flag === 'boolean') {
            existsData = [flag];
        }
        else {
            existsData = flag;
        }
    };
};
exports.spyOnStdout = () => jest.spyOn(global_1.default.mockStdout, 'write');
exports.stdoutCalledWith = (spyOnMock, messages) => {
    expect(spyOnMock).toBeCalledTimes(messages.length);
    messages.forEach((message, index) => {
        expect(spyOnMock.mock.calls[index][0]).toBe(message + os_1.EOL);
    });
};
exports.spyOnExec = () => jest.spyOn(global_1.default.mockChildProcess, 'exec');
// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.execCalledWith = (spyOnMock, messages) => {
    expect(spyOnMock).toBeCalledTimes(messages.length);
    messages.forEach((message, index) => {
        if (typeof message === 'string') {
            expect(spyOnMock.mock.calls[index][0]).toBe(message);
        }
        else {
            message.forEach((message, index2) => {
                if (typeof spyOnMock.mock.calls[index][index2] === 'object') {
                    expect(spyOnMock.mock.calls[index][index2]).toEqual(message);
                }
                else {
                    expect(spyOnMock.mock.calls[index][index2]).toBe(message);
                }
            });
        }
    });
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.testProperties = (object, checks) => {
    expect(typeof object).toBe('object');
    Object.keys(checks).forEach(key => {
        expect(object).toHaveProperty(key);
        if (typeof checks[key] === 'object') {
            expect(object[key]).toEqual(checks[key]);
        }
        else {
            expect(object[key]).toBe(checks[key]);
        }
    });
};
//# sourceMappingURL=utils.js.map